==> activity-common-api-1.1.43-20180823.055427-1-sources.jar: cn/com/duiba/activity/common/center/api/dto/wallet/WalletAccountDto.java <==
package cn.com.duiba.activity.common.center.api.dto.wallet;

import java.io.Serializable;
import java.util.Date;

/**
 * ClassName: WalletAccountDto.java <br/>
 * 
 * date: 2018年6月27日 <br/>
 * @author gey
 * @version V1.0
 * @since JDK 1.8
 */
public class WalletAccountDto implements Serializable{

	private static final long serialVersionUID = 7698815770477427482L;
	
    private Long id;
    //标题
    private String title;
    //每日体现额度
    private Integer everyDayLimit;
    //连续签到天数
    private Integer withdrawDay;
    //体现额度
    private Integer withdrawLimit;
    //定向app 数量
    private Integer appCount;
	//state   启用状态 默认0：关闭  1：开启
	private Integer state;
    /** 创建时间 */
    private Date gmtCreate;
	
	public Integer getAppCount() {
		return appCount;
	}
	public void setAppCount(Integer appCount) {
		this.appCount = appCount;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public Integer getEveryDayLimit() {
		return everyDayLimit;
	}
	public void setEveryDayLimit(Integer everyDayLimit) {
		this.everyDayLimit = everyDayLimit;
	}
	public Integer getWithdrawDay() {
		return withdrawDay;
	}
	public void setWithdrawDay(Integer withdrawDay) {
		this.withdrawDay = withdrawDay;
	}
	public Integer getWithdrawLimit() {
		return withdrawLimit;
	}
	public void setWithdrawLimit(Integer withdrawLimit) {
		this.withdrawLimit = withdrawLimit;
	}
	public Integer getState() {
		return state;
	}
	public void setState(Integer state) {
		this.state = state;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
}

==> activity-common-api-1.3.0-20180921.111628-1-sources.jar: cn/com/duiba/activity/common/center/api/dto/wallet/WalletAccountDto.java <==
package cn.com.duiba.activity.common.center.api.dto.wallet;

import java.io.Serializable;
import java.util.Date;

/**
 * ClassName: WalletAccountDto.java <br/>
 * 
 * date: 2018年6月27日 <br/>
 * @author gey
 * @version V1.0
 * @since JDK 1.8
 */
public class WalletAccountDto implements Serializable{

	private static final long serialVersionUID = 7698815770477427482L;
	
    private Long id;
    //标题
    private String title;
    //每日体现额度
    private Integer everyDayLimit;
    //连续签到天数
    private Integer withdrawDay;
    //体现额度
    private Integer withdrawLimit;
    //定向app 数量
    private Integer appCount;
	//state   启用状态 默认0：关闭  1：开启
	private Integer state;
	// 提现金额扣除账户类型  1:兑吧 2:开发者
	private Integer account;
	// 提现方式 0:现金 1:兑换
	private Integer drawType;
	//兑换规则
	private String changeRule;
	//如何赚钱提示
	private String incomeTips;
    /** 创建时间 */
    private Date gmtCreate;
	
	public Integer getAppCount() {
		return appCount;
	}
	public void setAppCount(Integer appCount) {
		this.appCount = appCount;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public Integer getEveryDayLimit() {
		return everyDayLimit;
	}
	public void setEveryDayLimit(Integer everyDayLimit) {
		this.everyDayLimit = everyDayLimit;
	}
	public Integer getWithdrawDay() {
		return withdrawDay;
	}
	public void setWithdrawDay(Integer withdrawDay) {
		this.withdrawDay = withdrawDay;
	}
	public Integer getWithdrawLimit() {
		return withdrawLimit;
	}
	public void setWithdrawLimit(Integer withdrawLimit) {
		this.withdrawLimit = withdrawLimit;
	}
	public Integer getState() {
		return state;
	}
	public void setState(Integer state) {
		this.state = state;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Integer getAccount() {
		return account;
	}

	public void setAccount(Integer account) {
		this.account = account;
	}

	public Integer getDrawType() {
		return drawType;
	}

	public void setDrawType(Integer drawType) {
		this.drawType = drawType;
	}

	public String getChangeRule() {
		return changeRule;
	}

	public void setChangeRule(String changeRule) {
		this.changeRule = changeRule;
	}

	public String getIncomeTips() {
		return incomeTips;
	}

	public void setIncomeTips(String incomeTips) {
		this.incomeTips = incomeTips;
	}
}
